@@ -20,6 +20,8 @@ class Adverlet(object):
 
     description = FieldProperty(IAdverlet['description'])
     default = FieldProperty(IAdverlet['default'])
+    wysiwyg = FieldProperty(IAdverlet['wysiwyg'])
+    newlines = FieldProperty(IAdverlet['newlines'])
 
     @setproperty
     def source(self, html):
