@@ -4,8 +4,8 @@
 
 __license__ = "GPL v.3"
 
-from z3c.widget.tiny.widget import TinyWidget
 from zope.component import getUtility
+from z3c.widget.tiny.widget import TinyWidget
 from ice.adverlet.interfaces import ISourceStorage
 
 class RichTextWidget(TinyWidget):
@@ -26,5 +26,4 @@ class RichTextWidget(TinyWidget):
 
     @property
     def mce_plugins(self):
-        tool = getUtility(ISourceStorage)
-        return ','.join(tool.mceplugins)
+        return ','.join(getUtility(ISourceStorage).mceplugins)
